#[repr(transparent)]pub struct AnactrlTog(pub u32);Expand description
USB PHY Analog Control Register
Tuple Fields
0: u32Implementations
Sourceimpl AnactrlTog
impl AnactrlTog
Sourcepub const fn set_lvi_en(&mut self, val: bool)
pub const fn set_lvi_en(&mut self, val: bool)
Vow voltage detector enable bit.
Sourcepub const fn pfd_clk_sel(&self) -> u8
pub const fn pfd_clk_sel(&self) -> u8
For normal USB operation, this bit field must remain at value 2’b00.
Sourcepub const fn set_pfd_clk_sel(&mut self, val: u8)
pub const fn set_pfd_clk_sel(&mut self, val: u8)
For normal USB operation, this bit field must remain at value 2’b00.
Sourcepub const fn dev_pulldown(&self) -> AnactrlTogDevPulldown
pub const fn dev_pulldown(&self) -> AnactrlTogDevPulldown
Setting this field to 1’b1 will enable the 15kohm pulldown resistors on both USB_DP and USB_DM pins
Sourcepub const fn set_dev_pulldown(&mut self, val: AnactrlTogDevPulldown)
pub const fn set_dev_pulldown(&mut self, val: AnactrlTogDevPulldown)
Setting this field to 1’b1 will enable the 15kohm pulldown resistors on both USB_DP and USB_DM pins