nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

PwdSet

Struct PwdSet 

#[repr(transparent)]
pub struct PwdSet(pub u32);
USB PHY Power-Down Register

Tuple Fields

0: u32

Implementations

Source

impl PwdSet

pub const fn txpwdfs(&self) -> PwdSetTxpwdfs

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_txpwdfs(&mut self, val: PwdSetTxpwdfs)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn txpwdibias(&self) -> PwdSetTxpwdibias

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_txpwdibias(&mut self, val: PwdSetTxpwdibias)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn txpwdv2i(&self) -> PwdSetTxpwdv2i

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_txpwdv2i(&mut self, val: PwdSetTxpwdv2i)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn rxpwdenv(&self) -> PwdSetRxpwdenv

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_rxpwdenv(&mut self, val: PwdSetRxpwdenv)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn rxpwd1pt1(&self) -> PwdSetRxpwd1pt1

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_rxpwd1pt1(&mut self, val: PwdSetRxpwd1pt1)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn rxpwddiff(&self) -> PwdSetRxpwddiff

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_rxpwddiff(&mut self, val: PwdSetRxpwddiff)

Note that this bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn rxpwdrx(&self) -> PwdSetRxpwdrx

This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled

pub const fn set_rxpwdrx(&mut self, val: PwdSetRxpwdrx)

This bit will be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of CTRL is enabled