#[repr(transparent)]pub struct Usb1VbusDetectTog(pub u32);Expand description
USB PHY VBUS Detect Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb1VbusDetectTog
impl Usb1VbusDetectTog
Sourcepub const fn vbusvalid_thresh(&self) -> Usb1VbusDetectTogVbusvalidThresh
pub const fn vbusvalid_thresh(&self) -> Usb1VbusDetectTogVbusvalidThresh
Sets the threshold for the VBUSVALID comparator
Sourcepub const fn set_vbusvalid_thresh(
&mut self,
val: Usb1VbusDetectTogVbusvalidThresh,
)
pub const fn set_vbusvalid_thresh( &mut self, val: Usb1VbusDetectTogVbusvalidThresh, )
Sets the threshold for the VBUSVALID comparator
Sourcepub const fn vbus_override_en(&self) -> Usb1VbusDetectTogVbusOverrideEn
pub const fn vbus_override_en(&self) -> Usb1VbusDetectTogVbusOverrideEn
VBUS detect signal override enable
Sourcepub const fn set_vbus_override_en(
&mut self,
val: Usb1VbusDetectTogVbusOverrideEn,
)
pub const fn set_vbus_override_en( &mut self, val: Usb1VbusDetectTogVbusOverrideEn, )
VBUS detect signal override enable
Sourcepub const fn sessend_override(&self) -> bool
pub const fn sessend_override(&self) -> bool
Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_sessend_override(&mut self, val: bool)
pub const fn set_sessend_override(&mut self, val: bool)
Override value for SESSEND The bit field provides the value for USB1_VBUS_DET_STAT[0] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn bvalid_override(&self) -> bool
pub const fn bvalid_override(&self) -> bool
Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_bvalid_override(&mut self, val: bool)
pub const fn set_bvalid_override(&mut self, val: bool)
Override value for B-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[1] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn avalid_override(&self) -> bool
pub const fn avalid_override(&self) -> bool
Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn set_avalid_override(&mut self, val: bool)
pub const fn set_avalid_override(&mut self, val: bool)
Override value for A-Device Session Valid The bit field provides the value for USB1_VBUS_DET_STAT[2] if USB_VBUS_DETECT[3] is set to value 1’b1
Sourcepub const fn vbusvalid_override(&self) -> bool
pub const fn vbusvalid_override(&self) -> bool
Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1
Sourcepub const fn set_vbusvalid_override(&mut self, val: bool)
pub const fn set_vbusvalid_override(&mut self, val: bool)
Override value for VBUS_VALID signal sent to USB controller The bit field provides the value for VBUS_VALID reported to the USB controller if the value of USB1_VBUS_DETECT[3] is set to 1’b1
Sourcepub const fn vbusvalid_sel(&self) -> Usb1VbusDetectTogVbusvalidSel
pub const fn vbusvalid_sel(&self) -> Usb1VbusDetectTogVbusvalidSel
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn set_vbusvalid_sel(&mut self, val: Usb1VbusDetectTogVbusvalidSel)
pub const fn set_vbusvalid_sel(&mut self, val: Usb1VbusDetectTogVbusvalidSel)
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn vbus_source_sel(&self) -> Usb1VbusDetectTogVbusSourceSel
pub const fn vbus_source_sel(&self) -> Usb1VbusDetectTogVbusSourceSel
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn set_vbus_source_sel(&mut self, val: Usb1VbusDetectTogVbusSourceSel)
pub const fn set_vbus_source_sel(&mut self, val: Usb1VbusDetectTogVbusSourceSel)
Selects the source of the VBUS_VALID signal reported to the USB controller This is one of the bit fields that selects the source of the VBUS_VALID signal reported to the USB controller
Sourcepub const fn id_override_en(&self) -> bool
pub const fn id_override_en(&self) -> bool
Enable ID override using the register field. This bit is only used if EXT_ID_OVERRIDE_EN = 1’b0.
Sourcepub const fn set_id_override_en(&mut self, val: bool)
pub const fn set_id_override_en(&mut self, val: bool)
Enable ID override using the register field. This bit is only used if EXT_ID_OVERRIDE_EN = 1’b0.
Sourcepub const fn id_override(&self) -> bool
pub const fn id_override(&self) -> bool
ID override value.
Sourcepub const fn set_id_override(&mut self, val: bool)
pub const fn set_id_override(&mut self, val: bool)
ID override value.
Sourcepub const fn ext_id_override_en(&self) -> Usb1VbusDetectTogExtIdOverrideEn
pub const fn ext_id_override_en(&self) -> Usb1VbusDetectTogExtIdOverrideEn
Enable ID override using the pin muxed value.
Sourcepub const fn set_ext_id_override_en(
&mut self,
val: Usb1VbusDetectTogExtIdOverrideEn,
)
pub const fn set_ext_id_override_en( &mut self, val: Usb1VbusDetectTogExtIdOverrideEn, )
Enable ID override using the pin muxed value.
Sourcepub const fn ext_vbus_override_en(&self) -> Usb1VbusDetectTogExtVbusOverrideEn
pub const fn ext_vbus_override_en(&self) -> Usb1VbusDetectTogExtVbusOverrideEn
Enable VBUS override using the pin muxed value.
Sourcepub const fn set_ext_vbus_override_en(
&mut self,
val: Usb1VbusDetectTogExtVbusOverrideEn,
)
pub const fn set_ext_vbus_override_en( &mut self, val: Usb1VbusDetectTogExtVbusOverrideEn, )
Enable VBUS override using the pin muxed value.
Sourcepub const fn vbusvalid_to_sessvalid(
&self,
) -> Usb1VbusDetectTogVbusvalidToSessvalid
pub const fn vbusvalid_to_sessvalid( &self, ) -> Usb1VbusDetectTogVbusvalidToSessvalid
Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator
Sourcepub const fn set_vbusvalid_to_sessvalid(
&mut self,
val: Usb1VbusDetectTogVbusvalidToSessvalid,
)
pub const fn set_vbusvalid_to_sessvalid( &mut self, val: Usb1VbusDetectTogVbusvalidToSessvalid, )
Selects the comparator used for VBUS_VALID This bit field controls the comparator used to report the VBUS_VALID results in USB1_VBUS_DETECT[3] between the VBUS_VALID comparator and the Session Valid comparator
Sourcepub const fn vbusvalid_5vdetect(&self) -> bool
pub const fn vbusvalid_5vdetect(&self) -> bool
no description available
Sourcepub const fn set_vbusvalid_5vdetect(&mut self, val: bool)
pub const fn set_vbusvalid_5vdetect(&mut self, val: bool)
no description available
Sourcepub const fn pwrup_cmps(&self) -> Usb1VbusDetectTogPwrupCmps
pub const fn pwrup_cmps(&self) -> Usb1VbusDetectTogPwrupCmps
Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector
Sourcepub const fn set_pwrup_cmps(&mut self, val: Usb1VbusDetectTogPwrupCmps)
pub const fn set_pwrup_cmps(&mut self, val: Usb1VbusDetectTogPwrupCmps)
Enables the VBUS_VALID comparator Powers up the comparator used for the VBUS_VALID detector
Sourcepub const fn discharge_vbus(&self) -> Usb1VbusDetectTogDischargeVbus
pub const fn discharge_vbus(&self) -> Usb1VbusDetectTogDischargeVbus
Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground
Sourcepub const fn set_discharge_vbus(&mut self, val: Usb1VbusDetectTogDischargeVbus)
pub const fn set_discharge_vbus(&mut self, val: Usb1VbusDetectTogDischargeVbus)
Controls VBUS discharge resistor This bit field controls a nominal 22kohm resistor between the USB1_VBUS pin and ground